@@ -31,7 +31,7 @@ class Network(object):
                  bgcolor="#ffffff",
                  font_color=False,
                  layout=None,
-                 heading=None):
+                 heading=""):
         """
         :param height: The height of the canvas
         :param width: The width of the canvas
@@ -65,6 +65,7 @@ class Network(object):
         self.options = Options(layout)
         self.widget = False
         self.node_ids = []
+        self.node_map = {}
         self.template = None
         self.conf = False
         self.path = os.path.dirname(__file__) + "/templates/template.html"
@@ -212,6 +213,7 @@ class Network(object):
             n = Node(n_id, shape, label=node_label, font_color=self.font_color, **options)
             self.nodes.append(n.options)
             self.node_ids.append(n_id)
+            self.node_map[n_id] = n.options
 
     def add_nodes(self, nodes, **kwargs):
         """
@@ -628,6 +630,16 @@ class Network(object):
         """
         return self.node_ids
 
+    def get_node(self, n_id):
+        """
+        Lookup node by ID and return it.
+        
+        :param n_id: The ID given to the node.
+        
+        :returns: dict containing node properties
+        """
+        return self.node_map[n_id]
+
     def get_edges(self):
         """
         This method returns an iterable list of edge objects
